==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Ynt");
define("_SUBJECT","Konu");
define("_PRIVATEMESSAGES","zel Mesajlarnz");
define("_CHECKALL","Hepsini aretle");
define("_FROM","Kimden");
define("_DATE","Tarih");
define("_DONTHAVEMESSAGES","Mesajnz yok");
define("_NOTREAD","Okunmam");
define("_MSGSTATUS","Mesaj Durumu");
define("_PRIVATEMESSAGE","zel Mesaj");
define("_INDEX","ndeks");
define("_SENT","Gnderilme");
define("_PREVIOUSMESSAGE","nceki Mesaj");
define("_NEXTMESSAGE","Sonraki Mesaj");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","Gnderme Hakknda");
define("_ALLREGCANPOST","Tm kaytl kullanclar zel mesaj gnderebilir");
define("_TO","Kime");
define("_MESSAGEICON","Mesaj konu");
define("_MESSAGE","Mesaj");
define("_HTML","HTML");
define("_PMON","Ak");
define("_PMOFF","Kapal");
define("_BBCODE","BBCode");
define("_WROTE","yazd");
define("_OPTIONS","Seenekler");
define("_HTMLDISSABLE","HTML'i Geersiz Kl");
define("_BBCODEDISSABLE","<a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a>'u Geersiz Kl");
define("_SMILEDISSABLE","<a href=\"bb_smilies.php\" target=\"_blank\"><i>Smiley</i></a>'leri Geersiz Kl");
define("_CANCELREPLY","Cevap ptali");
define("_CANCELSEND","Gnderme ptali");
define("_CLEAR","Temizle");
define("_SUBMIT","Gnder");
define("_USERNOTINDB","Vertabannda byle bir kullanc yok.");
define("_CHECKNAMEANDTRY","Ltfen ismi kontrol ederek tekrar deneyin.");
define("_MSGPOSTED","Mesajnz gnderildi.");
define("_RETURNTOPMSG","zel mesajlarnz yenilemek iin tklayn.");
define("_MSGDELETED","Mesajlarnz silindi.");
define("_BBGO","git");
define("_BBNEWPMSG","Yeni Mesaj");
define("_BBNONEWPMSG","Yeni Mesaj Yok");
define("_BBTOTALPMSG","Toplam Mesaj");
define("_BBEMPTYPMSG","Mesajnz yok");
define("_BBLOGIN","zel mesajlarnz kontrol etmek iin giri yapn");
define("_BBPMSG","zel Mesaj");
define("_BBINBOX","Gelen Kutusu");
define("_BBSELECTFORUM","Bir Forum Sein");
define("_BBNOFORUM","Baka Forum Yok");
define("_BBBANNED","Ban'lendi");
define("_CLICKSMILEBUTTONS","Mesajnza eklemek istediiniz smiley'e tklayn:");
define("_CLICKCODEBUTTONS","Mesajnza eklemek istediiniz BBCode'a tklayn:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Ynt");
define("_SUBJECT","Konu");
define("_PRIVATEMESSAGES","zel Mesajlarnz");
define("_CHECKALL","Hepsini aretle");
define("_FROM","Kimden");
define("_DATE","Tarih");
define("_DONTHAVEMESSAGES","Mesajnz yok");
define("_NOTREAD","Okunmam");
define("_MSGSTATUS","Mesaj Durumu");
define("_PRIVATEMESSAGE","zel Mesaj");
define("_INDEX","ndeks");
define("_SENT","Gnderilme");
define("_PREVIOUSMESSAGE","nceki Mesaj");
define("_NEXTMESSAGE","Sonraki Mesaj");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","Gnderme Hakknda");
define("_ALLREGCANPOST","Tm kaytl kullanclar zel mesaj gnderebilir");
define("_TO","Kime");
define("_MESSAGEICON","Mesaj konu");
define("_MESSAGE","Mesaj");
define("_HTML","HTML");
define("_PMON","Ak");
define("_PMOFF","Kapal");
define("_BBCODE","BBCode");
define("_WROTE","yazd");
define("_OPTIONS","Seenekler");
define("_HTMLDISSABLE","HTML'i Geersiz Kl");
define("_BBCODEDISSABLE","<a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a>'u Geersiz Kl");
define("_SMILEDISSABLE","<a href=\"bb_smilies.php\" target=\"_blank\"><i>Smiley</i></a>'leri Geersiz Kl");
define("_CANCELREPLY","Cevap ptali");
define("_CANCELSEND","Gnderme ptali");
define("_CLEAR","Temizle");
define("_SUBMIT","Gnder");
define("_USERNOTINDB","Vertabannda byle bir kullanc yok.");
define("_CHECKNAMEANDTRY","Ltfen ismi kontrol ederek tekrar deneyin.");
define("_MSGPOSTED","Mesajnz gnderildi.");
define("_RETURNTOPMSG","zel mesajlarnz yenilemek iin tklayn.");
define("_MSGDELETED","Mesajlarnz silindi.");
define("_BBGO","git");
define("_BBNEWPMSG","Yeni Mesaj");
define("_BBNONEWPMSG","Yeni Mesaj Yok");
define("_BBTOTALPMSG","Toplam Mesaj");
define("_BBEMPTYPMSG","Mesajnz yok");
define("_BBLOGIN","zel mesajlarnz kontrol etmek iin giri yapn");
define("_BBPMSG","zel Mesaj");
define("_BBINBOX","Gelen Kutusu");
define("_BBSELECTFORUM","Bir Forum Sein");
define("_BBNOFORUM","Baka Forum Yok");
define("_BBBANNED","Ban'lendi");
define("_CLICKSMILEBUTTONS","Mesajnza eklemek istediiniz smiley'e tklayn:");
define("_CLICKCODEBUTTONS","Mesajnza eklemek istediiniz BBCode'a tklayn:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
